@@ -26,6 +26,10 @@
 #include <QPainter>
 #include <QStyledItemDelegate>
 
+#ifdef KF5_USE_PURPOSE
+namespace Purpose { class Menu; }
+#endif
+
 #include "definitions.h"
 #include "ui_renderwidget_ui.h"
 
@@ -198,6 +202,8 @@ private slots:
     void adjustSpeed(int videoQuality);
     /** @brief Display warning on proxy rendering. */
     void slotProxyWarn(bool enableProxy);
+    /** @brief User shared a rendered file, give feedback. */
+    void slotShareActionFinished(const QJsonObject &output, int error, const QString &message);
 
 private:
     Ui::RenderWidget_UI m_view;
@@ -208,8 +214,12 @@ private:
     bool m_blockProcessing;
     QString m_renderer;
     KMessageWidget *m_infoMessage;
+    KMessageWidget *m_jobInfoMessage;
     QMap<int, QString>m_errorMessages;
 
+#ifdef KF5_USE_PURPOSE
+    Purpose::Menu *m_shareMenu;
+#endif
     void parseMltPresets();
     void parseProfiles(const QString &selectedProfile = QString());
     void parseFile(const QString &exportFile, bool editable);
