@@ -776,16 +776,16 @@ CollapsibleEffect *EffectStackView2::getEffectByIndex(int ix)
     return nullptr;
 }
 
-void EffectStackView2::slotUpdateEffectParams(const QDomElement &old, const QDomElement &e, int ix)
+void EffectStackView2::slotUpdateEffectParams(const QDomElement &old, const QDomElement &e, int ix, bool update)
 {
     if (m_status == TIMELINE_TRACK) {
-        emit updateEffect(nullptr, m_trackindex, old, e, ix, false);
+        emit updateEffect(nullptr, m_trackindex, old, e, ix, false, update);
     } else if (m_status == TIMELINE_CLIP && m_clipref) {
-        emit updateEffect(m_clipref, -1, old, e, ix, false);
+        emit updateEffect(m_clipref, -1, old, e, ix, false, update);
         // Make sure the changed effect is currently displayed
         slotSetCurrentEffect(ix);
     } else if (m_status == MASTER_CLIP) {
-        emit updateMasterEffect(m_masterclipref->clipId(), old, e, ix);
+        emit updateMasterEffect(m_masterclipref->clipId(), old, e, ix, false, update);
     }
     m_scrollTimer.start();
 }
